@@ -1,24 +1,10 @@
 /*
-    Copyright (c) 2014 Christian Mollekopf <mollekopf@kolabsys.com>
-    Copyright (c) 2014 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
+    SPDX-FileCopyrightText: 2014 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
 #include <QTest>
 
 #include <krecursivefilterproxymodel.h>
@@ -30,11 +16,11 @@ class ModelSignalSpy : public QObject {
     Q_OBJECT
 public:
     explicit ModelSignalSpy(QAbstractItemModel &model) {
-        connect(&model, SIGNAL(rowsInserted(QModelIndex, int, int)), this, SLOT(onRowsInserted(QModelIndex,int,int)));
-        connect(&model, SIGNAL(rowsRemoved(QModelIndex, int, int)), this, SLOT(onRowsRemoved(QModelIndex,int,int)));
-        connect(&model, SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)), this, SLOT(onRowsAboutToBeInserted(QModelIndex,int,int)));
-        connect(&model, SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)), this, SLOT(onRowsAboutToBeRemoved(QModelIndex,int,int)));
-        connect(&model, SIGNAL(rowsMoved(QModelIndex, int, int, QModelIndex, int)), this, SLOT(onRowsMoved(QModelIndex,int,int, QModelIndex, int)));
+        connect(&model, SIGNAL(rowsInserted(QModelIndex,int,int)), this, SLOT(onRowsInserted(QModelIndex,int,int)));
+        connect(&model, SIGNAL(rowsRemoved(QModelIndex,int,int)), this, SLOT(onRowsRemoved(QModelIndex,int,int)));
+        connect(&model, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)), this, SLOT(onRowsAboutToBeInserted(QModelIndex,int,int)));
+        connect(&model, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)), this, SLOT(onRowsAboutToBeRemoved(QModelIndex,int,int)));
+        connect(&model, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)), this, SLOT(onRowsMoved(QModelIndex,int,int,QModelIndex,int)));
         connect(&model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(onDataChanged(QModelIndex,QModelIndex)));
         connect(&model, SIGNAL(layoutChanged()), this, SLOT(onLayoutChanged()));
         connect(&model, SIGNAL(modelReset()), this, SLOT(onModelReset()));
@@ -90,7 +76,7 @@ public:
         setSourceModel(sourceModel);
     }
 
-    virtual bool acceptRow(int sourceRow, const QModelIndex &sourceParent) const
+    bool acceptRow(int sourceRow, const QModelIndex &sourceParent) const override
     {
         // qDebug() << sourceModel()->index(sourceRow, 0, sourceParent).data().toString() << sourceModel()->index(sourceRow, 0, sourceParent).data(Qt::UserRole+1).toBool();
         return sourceModel()->index(sourceRow, 0, sourceParent).data(Qt::UserRole+1).toBool();
@@ -131,7 +117,7 @@ static QString treeAsString(const QAbstractItemModel &model, const QModelIndex &
 static void fillModel(QStandardItemModel &model, const QString &str)
 {
     QCOMPARE(str.count('['), str.count(']'));
-    QStandardItem *item = 0;
+    QStandardItem *item = nullptr;
     QString data;
     for ( int i = 0 ; i < str.length() ; ++i ) {
         const QChar ch = str.at(i);
@@ -623,7 +609,7 @@ private Q_SLOTS:
 private:
     QStandardItem *itemByText(const QStandardItemModel& model, const QString &text) const {
         QModelIndexList list = model.match(model.index(0, 0), Qt::DisplayRole, text, 1, Qt::MatchRecursive);
-        return list.isEmpty() ? 0 : model.itemFromIndex(list.first());
+        return list.isEmpty() ? nullptr : model.itemFromIndex(list.first());
     }
 };
 
