@@ -1,30 +1,14 @@
 /*
-    Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef PROXY_MODEL_TEST_H
 #define PROXY_MODEL_TEST_H
 
-#include <QtTest>
-#include <QtCore>
-#include <QTestEvent>
-#include <QItemSelectionRange>
 #include <QAbstractProxyModel>
+#include <QTest>
 
 #include "dynamictreemodel.h"
 #include "indexfinder.h"
@@ -400,7 +384,7 @@ protected:
 
     QStringList namedTests()
     {
-        return m_testNames.toList();
+        return m_testNames.values();
     }
 
     void noopTest(const QString &name)
@@ -756,7 +740,8 @@ PROXYMODELTESTSUITE_EXPORT uint qHash(const QVariant &var);
         QList<int> testObjects; \
         QStringList arguments; \
         bool ok; \
-        Q_FOREACH(const QString &arg, app.arguments()) \
+        const auto lst = app.arguments(); \
+        for (const QString &arg : lst) \
         { \
             int testObject = arg.toInt(&ok); \
             if (arg == "-count") \
